\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cjtarticle}[2018/09/04 Chinese Journal of Turbomachinery Article class]
 
% this class is based on the KOMA article class scrartcl 
% in twocolumn and twoside mode
\LoadClass[twocolumn,twoside]{scrartcl}

% set all lengths for the page layout
\RequirePackage[pass]{geometry}
\geometry{%
left=-7.5mm,%
right=15mm,
}
\setlength{\paperwidth}{210mm}
\setlength{\paperheight}{285mm}
\setlength{\textwidth}{177mm}
\setlength{\textheight}{237mm}
\setlength{\columnsep}{7mm}
\setlength{\topmargin}{-12mm}
\setlength{\headsep}{9mm}
\setlength{\evensidemargin}{-8.5mm}
\setlength{\oddsidemargin}{-8.5mm}
\setlength{\headheight}{23pt}
\setlength{\footheight}{20pt}
\setlength{\footskip}{10mm}

% define section and subsection spacings
\parindent7mm
\RedeclareSectionCommand[ 
  beforeskip=0.2mm, 
  afterskip=1mm 
]{section}
\RedeclareSectionCommand[ 
  beforeskip=0.001mm, 
  afterskip=0.5mm 
]{subsection}

% change section, subsection fonts to serif fonts
\addtokomafont{disposition}{\rmfamily}

% provide bibtex or biblatex for the references
\RequirePackage{ifthen}
\newboolean{usebibtex}
\setboolean{usebibtex}{false}
\DeclareOption{bibtex}{\setboolean{usebibtex}{true}}
\newcommand{\cjtreferences}[0]{~\hfill References \hfill~\newline \vspace{-2mm}}


%\DeclareOption{draft}{\renewcommand{\headlinecolor}{\color{green}}}
%\DeclareOption{final}{\renewcommand{\headlinecolor}{\color{blue}}}
\DeclareOption{onecolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

\RequirePackage{amsmath}
\RequirePackage{ifxetex}
% the next line would include links from the references to the page 
% where it is cited
%\RequirePackage[pagebackref,breaklinks]{hyperref}
\RequirePackage[breaklinks]{hyperref}
\hypersetup{
colorlinks,
citecolor=blue,
filecolor=green,
linkcolor=red,
urlcolor=yellow
}
\ifxetex
   \RequirePackage{mathspec}
   \RequirePackage{fontspec}
   \setmainfont{TeX Gyre Termes}[Scale=0.925,FakeStretch=1.1,PunctuationSpace=2]
   \RequirePackage{polyglossia}
   \setdefaultlanguage{english}
\else
   \RequirePackage{tgtermes}
   \RequirePackage[T1]{fontenc}
   \RequirePackage[english]{babel}
\fi

% support for chinese characters
\RequirePackage[UTF8]{ctex}

\ifthenelse{\boolean{usebibtex}}%
{\RequirePackage[style=ieee,backend=bibtex]{biblatex}}%
{\RequirePackage[style=ieee,backend=biber]{biblatex}}%

\renewcommand{\bibfont}{\small}
\RequirePackage{doi}
\RequirePackage{url}
\RequirePackage{graphicx}
\RequirePackage{multirow}
\RequirePackage{xcolor}
\RequirePackage[affil-it]{authblk}

% define counters for the journal issue
\newcounter{journalyear}
\newcounter{journalvolume}
\newcounter{journalnumber}
% default, but non-meaningful values
\setcounter{journalyear}{2018}
\setcounter{journalvolume}{1}
\setcounter{journalnumber}{1}

% titlepage settings
% add parenthesis around the affiliation
\newcommand{\affiliation}[1]{\affil{{(#1)}}}

% redefine the author font to sans serif
\renewcommand\Authfont{\bfseries \sffamily \large \selectfont}
% redefine the affiliation in italic font
\renewcommand\Affilfont{\rmfamily \normalfont \itshape \normalsize \selectfont}
% redefine the title font to normalfont
\setkomafont{title}{\normalfont\huge\rmfamily}
% set spacing between author and affiliation
\setlength{\affilsep}{0mm}
% set length between header and title
\extratitle{\vspace{-17mm}}
% set spacing between title and author
\subtitle{\vspace{11mm}}
% set spacing between affiliation and abstract
\date{\vspace{-12mm}}

% define the one column part of the article, i.e.
% the title, author, abstract and key words
\RequirePackage{multicol}
\newenvironment{cjttitle}{%
  \begin{@twocolumnfalse}%
      \begin{center}% 
        \begin{minipage}{160mm}
        }%
        {
        \end{minipage}%
      \end{center}%
  \end{@twocolumnfalse}
}
  
% define the abstract word to be sans serif and bold face
\renewcommand{\abstract}{{\bfseries \sffamily Abstract:}}
% define keywords and DOI 
\newenvironment{keywords}{\vspace{1mm} {\bfseries \sffamily
    Keywords:}}{\\[4mm]{\bfseries \sffamily DOI}:\paperdoi\\[0mm]}

\RequirePackage{supertabular}
% environment for the nomenvclature, with superscripts and indices commands
\newenvironment{nomenclature}{%
  \noindent
  {\bfseries \large Nomenclature:}
  \begin{multicols}{2}
    \begin{supertabular}{ll}%
        }{%
      \end{supertabular}
    \end{multicols}
    \vspace{5mm}
}
\newcommand{\superscripts}[0]{\\ \multicolumn{2}{l}{\bfseries Superscripts}\\}
\newcommand{\indices}[0]{\\ \multicolumn{2}{l}{\bfseries Indices:}\\}

% define headers and footers 
%\RequirePackage[footsepline]{scrlayer-scrpage}
\RequirePackage{lastpage}
\RequirePackage{scrlayer-scrpage}
\clearscrheadfoot
\pagestyle{scrheadings}

\RequirePackage{tikz}
\RequirePackage{tikzpagenodes}

% set the font for the header as a normalfont
\setkomafont{pageheadfoot}{\normalfont\normalcolor}
%\setkomafont{pagenumber}{\normalfont\bfseries}

% add a frame indicating the jounral final page size
\newcommand{\pageframe}{\tikz[remember picture,overlay] 
  \draw [red,line width=2pt]
  (current page.south west)
  rectangle
  (current page.north east)
  ;}

\lofoot[\footnotesize \itshape 20-23 October, 2022, Kunming, China]{}
\rofoot[\href{http://citc.cftn.cn}{https://citc.cftn.cn/}]{}
% set the logo and journal name in the header
\lohead[\href{http://citc.cftn.cn}{\includegraphics[width=45mm]{cjt_logo.png}}%
      ]{\footnotesize \itshape The 5$^{th}$ Chinese International Turbomachinery Conference}
\rohead[\footnotesize \itshape The 5$^{th}$ Chinese International Turbomachinery Conference]{\footnotesize \thepage\ of \pageref{LastPage}}
\rehead{\footnotesize \thepage\ of \pageref{LastPage}}
\lehead{\footnotesize \itshape The 5$^{th}$ Chinese International Turbomachinery Conference}%

% draw a black frame indicating the pagesize of the journal 
\chead[\pageframe]{\pageframe} 
